# Two-Disc Cycloidal Gearbox Design

#### 1. Project Description
The two-disc cycloidal gearbox is designed to convert high-speed, low-torque input from a stepper motor into low-speed, high-torque output. It utilizes two synchronized cycloidal discs that rotate in opposite phases, interacting with drive pins to transmit motion to an output shaft.

This configuration minimizes backlash and distributes load across multiple contact points, offering smooth and powerful transmission. The system is fully enclosed and features multiple mounting options for external attachments.

#### 2. Application & Use Cases

##### Applications
- Robotics joints and arms
- CNC rotary tables
- Precision camera mounts
- Automated actuators
- Small-scale industrial machines

##### How to Use
- Mount the gearbox base to your motor using the provided holes.

- Connect the NEMA-17 motor shaft to the input via the motor shaft connector.

- Attach your load or mechanism to the output shaft area.

- Power the motor through a driver board and microcontroller (e.g., Arduino).

- Control the motion using programmed step sequences.

    - Ensure lubrication (grease) between the discs and drive pins for smoother performance and longer lifespan.

#### 3.  Engineering Drawings

##### Description
The design is a compact, scalable two-disc cycloidal gearbox intended for high-torque, low-speed applications. Its parametric structure makes it easy to adapt in size and material. The current prototype has a 90 mm diameter and 54 mm height.

To clearly illustrate the internal mechanics, structural design, and assembly steps, the following visuals are provided:

- Included Media
    - Assembly Video – starts with an exploded view and step-by-step buildup

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

    - Disassembly Video – shows teardown process in reverse order

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

    - Transparent Body Image – reveals internal components without hiding the casing

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

- Visual Assets & Drawings
    - Engineering Drawing Sheet

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

    - Cross-Sectional Analysis (x2)

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

    - Isometric View

        <p align="center">
      <img src="../../images/week04/insert.jpg" style="border: 2px solid black;" />
          </p>

#### 4. List of Materials & Components

- ##### Standard Components

| Part          | Quantity | Approx. Size                                       |
| ------------- | -------- | -------------------------------------------------- | 
| Bearing       | 2        | Ø65 mm (outer) × Ø50 mm (inner) × 7 mm (thickness) |
| Bearing       | 4        | Ø32 mm (outer) × Ø20 mm (inner) × 7 mm (thickness) |
| Stepper Motor | 1        | NEMA-17                                            |

- ##### Bolts & Nuts (*with available size approximations*)

Note: If a bolt is slightly longer than needed, it can be trimmed using a saw. Nut sizes should fit snugly but not too tight.

1. (A) Connecting Base to Base Cover
    - 7 × Flat Head Machine Screws (Type B)
        - Size: M4 × 45 mm
        - Head Diameter: ~7.5 mm 
    - 7 × M4 Hex Nuts
        - Edge-to-Edge: ~6.9 mm
        - Thickness: ~3.2 mm

2. (B) Drive Pins Area (Replaces 5 mm Pins)
    - 4 × M3 × 50 mm Bolts (hex or socket head)
        - Head Diameter: ~5.5 mm
    - 4 × M3 Hex Nuts
        - Edge-to-Edge: ~5.5 mm
        - Thickness: ~2.4 mm

3. (C) Mounting Points on Top of the Gearbox
    - 7 × M4 Hex Nuts
        - Edge-to-Edge: ~6.9 mm
        - Thickness: ~3.2 mm

4. (D) Shaft Connector
    - 2 × M3 × 40 mm Bolts
        - Head Diameter: ~5.5 mm
    - 2 × M3 Hex Nuts
        - Edge-to-Edge: ~5.5 mm
        - Thickness: ~2.4 mm

5. (E) NEMA-17 Shaft Connector
    - 1 × M3 × 6 mm Bolt (may require sanding)
        - Head Diameter: ~5.5 mm
    - 1 × M3 Hex Nut
        - Edge-to-Edge: ~5.5 mm
        - Thickness: ~2.4 mm

6. (F) NEMA-17 Connector
    - 4 × M3 × 15 mm Bolts
        - Head Diameter: ~5 mm

- ##### 3D-Printed Components
    - Material: PLA (tested), PETG (recommended for durability)
    - Parts: Housing, base cover, discs, shaft connectors, output caps, circlips
    - Infill: Suggested 40% or more for torque applications

#### 5. Cycloidal Drive Strength Analysis

---

##### **1. Motor Output Torque**

* **Motor Stall Torque**: 0.45 Nm
* **Gear Ratio**: 21:1
* **Estimated Efficiency**: 85%

$$
\text{Output Torque} = 0.45 \times 21 \times 0.85 = \boxed{8.03 \, \text{Nm}}
$$

---

##### **2. Load Handling Capability (Based on PLA Disc)**

###### PLA Parameters:

* **Yield Strength of PLA**: 50 MPa
* **Safety Factor**: 3 → Allowable stress = 16.7 MPa
* **Contact Area (per lobe)**: 5 mm²
* **Lobes in contact**: 4
* **Radius from center to lobe force point**: 33.5 mm = 0.0335 m
* **Infill Density**: 25%

###### Calculations:

* **Force per lobe**:

$$
F_{\text{lobe}} = 16.7 \times 10^6 \times 5 \times 10^{-6} = 83.5 \, \text{N}
$$

* **Total force from 4 lobes**:

$$
F_{\text{total}} = 4 \times 83.5 = 334 \, \text{N}
$$

* **Torque handling at 33.5 mm radius**:

$$
\tau = 334 \times 0.0335 = 11.2 \, \text{Nm}
$$

* **Account for 25% infill**:

$$
\tau_{\text{safe}} = 11.2 \times 0.25 = \boxed{2.8 \, \text{Nm}}
$$

---

##### **3. Drive Pin Strength (Bolts with PLA Sleeves)**

###### Assumption:

* Bolts used instead of precision 5 mm mild steel pins
* Outer diameter maintained at **5 mm** using **PLA sleeves**
* Inner bolt shaft assumed 4 mm (typical M4 bolt shank)
* Steel Yield Strength: 260 MPa

- **Cross-sectional Area (4 mm bolt)**:

$$
A = \frac{\pi D^2}{4} = \frac{\pi \cdot 4^2}{4} = 12.57 \, \text{mm}^2
$$

- **Force per bolt**:

$$
F_{\text{bolt}} = 260 \times 12.57 = 3,268.2 \, \text{N}
$$

- **Total force (4 bolts)**:

$$
F_{\text{total}} = 4 \times 3,268.2 = 13,072.8 \, \text{N}
$$

- **Torque capacity**:

$$
\tau = 13,072.8 \times 0.0335 = \boxed{437.9 \, \text{Nm}} \quad \text{(Safe✅)}
$$

> Note: **PLA sleeves** do not contribute significantly to strength — they act as spacers or guides. Only **steel bolts** are load-bearing.

---

##### **4. Max Load at 50 mm Arm**

$$
F = \frac{\tau_{\text{safe}}}{r} = \frac{2.8}{0.05} = 56 \, \text{N}
$$

$$
\text{Mass} = \frac{56}{9.81} = \boxed{5.7 \, \text{kg}}
$$

---

##### Final Summary Table

| Category                    | Value    | Safe?                    |
| --------------------------- | -------- | ------------------------ |
| Motor Stall Torque          | 0.45 Nm  | ✅                        |
| Output Torque               | 8.03 Nm  | ❌ Exceeds PLA safe limit |
| PLA Torque Limit            | 2.8 Nm   | ✅                        |
| Bolt + PLA Pin Torque Limit | 437.9 Nm | ✅ (way overbuilt)        |
| Max Load (at 50 mm arm)     | 5.7 kg   | ✅                        |

---

##### Final Conclusion

The **cycloidal drive system is likely to fail at the PLA disc lobes under full output torque**, especially if printed with only **25% infill**. Although the **bolts (with PLA sleeves)** acting as drive pins are structurally sufficient, the **PLA disc is the mechanical weak point**.

##### If tested:

* The drive **will function under light loads (below \~5.7 kg at 50 mm arm)**.
* Under full load or high-torque demand, **plastic deformation or cracking is expected at the lobes**.
* The bolts will hold without issue, but **localized PLA wear or failure around the lobes and sleeves is likely.**

##### Recommendations:

* Increase **infill to at least 75%** or use a stronger material like **PETG**.
* Consider **fillet reinforcement** around lobes to distribute stress.
* Reduce gear ratio or torque output if high load isn't needed.